Estimation of Distribution Algorithms (EDA)
===========================================

.. autoclass:: pypop7.optimizers.eda.eda.EDA



.. toctree::
   :maxdepth: 2
   :caption: EDAs:

   rpeda
   aemna
   emna
   umda
